eric6/Preferences/ShortcutsDialog.py

changeset 7960
e8fc383322f7
parent 7923
91e843545d9a
child 8043
0acf98cd089a
child 8143
2c730d5fd177
diff -r 44e15eda6506 -r e8fc383322f7 eric6/Preferences/ShortcutsDialog.py
--- a/eric6/Preferences/ShortcutsDialog.py	Tue Jan 05 18:28:31 2021 +0100
+++ b/eric6/Preferences/ShortcutsDialog.py	Wed Jan 06 13:47:01 2021 +0100
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing a dialog for the configuration of eric6's keyboard
+Module implementing a dialog for the configuration of eric's keyboard
 shortcuts.
 """
 
@@ -25,7 +25,7 @@
 
 class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
     """
     Class implementing a dialog for the configuration of eric6's keyboard
     shortcuts.
     
     @signal updateShortcuts() emitted when the user pressed the dialogs OK
@@ -195,7 +195,7 @@
         
         else:
             self.helpViewerItem = self.__generateCategoryItem(
-                self.tr("eric6 Web Browser"))
+                self.tr("eric Web Browser"))
             for act in helpViewer.getActions():
                 self.__generateShortcutItem(self.helpViewerItem, act, True)
         
@@ -25,7 +25,7 @@
 class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
     """
-    Class implementing a dialog for the configuration of eric6's keyboard
+    Class implementing a dialog for the configuration of eric's keyboard
     shortcuts.
     

eric ide

mercurial